/* GCompris - louis_braille_data.js
 *
 * SPDX-FileCopyrightText: 2014 Arkit Vora <arkitvora123@gmail.com>
 *
 *   SPDX-License-Identifier: GPL-3.0-or-later
 */

var baseUrl = "qrc:/gcompris/src/activities/louis-braille/resource/"

var dataset = [
            {
                 "text": qsTr("Born on January 4th 1809 in Coupvray near Paris in France."),
                 "year": "1809",
                 "img": baseUrl + "louis.webp"
             },
             {
                 "text": qsTr("Louis Braille injured his right eye with a stitching awl from his father's workshop."),
                 "year": "1812",
                 "img": baseUrl + "stitching_awl.svg"
             },
             {
                 "text": qsTr("At the age of three, Louis became blind due to a severe infection that spread to his left eye."),
                 "year": "1812",
                 "img": baseUrl + "blind.svg"
             },
             {
                 "text": qsTr("At the age of 10, he was sent to Paris to study at the Royal Institute for Blind Youth."),
                 "year": "1819",
                 "img": baseUrl + "paris.svg"
             },
             {
                 "text": qsTr("He impressed his classmates and began to play the piano and the organ."),
                 "year": "1820",
                 "img": baseUrl + "piano.svg"
             },
             {
                 "text": qsTr("Charles Barbier, a French soldier, visited his school and shared his invention of night writing, a code of 12 raised dots to share information on battlefields."),
                 "year": "1821",
                 "img": baseUrl + "night_writing.svg"
             },
             {
                 "text": qsTr("Louis trimmed Barbier's 12 dots into 6 and invented the braille system."),
                 "year": "1824",
                 "img": baseUrl + "braille.svg"
             },
             {
                 "text": qsTr("He became a teacher after graduating and promoted his method while secretly teaching it at the Institute."),
                 "year": "1828",
                 "img": baseUrl + "teach.svg"
             },
             {
                 "text": qsTr("He revised and extended braille to include mathematics, symbols, punctuation and music notations."),
                 "year": "1837",
                 "img": baseUrl + "maths.svg"
             },
             {
                 "text": qsTr("He died of tuberculosis. He is buried in the Pantheon in Paris. A monument is erected to honor him."),
                 "year": "1852",
                 "img": baseUrl + "statue.svg"
             },
             {
                 "text": qsTr("Braille got accepted as a world wide standard. Louis Braille proved that if you have motivation you can do incredible things."),
                 "year": "After his Death",
                 "img": baseUrl + "world.svg"
             }
        ];
